@@ -29,9 +29,9 @@
 G_BEGIN_DECLS
 
 #if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
-#define rb_debug(...) rb_debug_real (__func__, __FILE__, __LINE__, __VA_ARGS__)
+#define rb_debug(...) rb_debug_real (__func__, __FILE__, __LINE__, TRUE, __VA_ARGS__)
 #elif defined(__GNUC__) && __GNUC__ >= 3
-#define rb_debug(...) rb_debug_real (__FUNCTION__, __FILE__, __LINE__, __VA_ARGS__)
+#define rb_debug(...) rb_debug_real (__FUNCTION__, __FILE__, __LINE__, TRUE, __VA_ARGS__)
 #else
 #define rb_debug
 #endif
@@ -39,10 +39,15 @@ G_BEGIN_DECLS
 void rb_debug_init             (gboolean debug);
 void rb_debug_init_match       (const char *match);
 
+gboolean rb_debug_matches      (const char *func,
+				const char *file);
 void rb_debug_real             (const char *func,
 				const char *file,
 				int line,
-				const char *format, ...) G_GNUC_PRINTF (4, 5);
+				gboolean newline,
+				const char *format, ...) G_GNUC_PRINTF (5, 6);
+
+char **rb_debug_get_args       (void);
 
 void rb_debug_stop_in_debugger (void);
 
