@@ -145,7 +145,56 @@ rb_marshal_BOOLEAN__POINTER (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* INT:VOID (./rb-marshal.list:3) */
+/* BOOLEAN:STRING,STRING,OBJECT (./rb-marshal.list:3) */
+extern void rb_marshal_BOOLEAN__STRING_STRING_OBJECT (GClosure     *closure,
+                                                      GValue       *return_value,
+                                                      guint         n_param_values,
+                                                      const GValue *param_values,
+                                                      gpointer      invocation_hint,
+                                                      gpointer      marshal_data);
+void
+rb_marshal_BOOLEAN__STRING_STRING_OBJECT (GClosure     *closure,
+                                          GValue       *return_value,
+                                          guint         n_param_values,
+                                          const GValue *param_values,
+                                          gpointer      invocation_hint,
+                                          gpointer      marshal_data)
+{
+  typedef gboolean (*GMarshalFunc_BOOLEAN__STRING_STRING_OBJECT) (gpointer     data1,
+                                                                  gpointer     arg_1,
+                                                                  gpointer     arg_2,
+                                                                  gpointer     arg_3,
+                                                                  gpointer     data2);
+  register GMarshalFunc_BOOLEAN__STRING_STRING_OBJECT callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+  gboolean v_return;
+
+  g_return_if_fail (return_value != NULL);
+  g_return_if_fail (n_param_values == 4);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_BOOLEAN__STRING_STRING_OBJECT) (marshal_data ? marshal_data : cc->callback);
+
+  v_return = callback (data1,
+                       g_marshal_value_peek_string (param_values + 1),
+                       g_marshal_value_peek_string (param_values + 2),
+                       g_marshal_value_peek_object (param_values + 3),
+                       data2);
+
+  g_value_set_boolean (return_value, v_return);
+}
+
+/* INT:VOID (./rb-marshal.list:4) */
 extern void rb_marshal_INT__VOID (GClosure     *closure,
                                   GValue       *return_value,
                                   guint         n_param_values,
@@ -188,7 +237,7 @@ rb_marshal_INT__VOID (GClosure     *closure,
   g_value_set_int (return_value, v_return);
 }
 
-/* OBJECT:OBJECT (./rb-marshal.list:4) */
+/* OBJECT:OBJECT (./rb-marshal.list:5) */
 extern void rb_marshal_OBJECT__OBJECT (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
@@ -233,7 +282,7 @@ rb_marshal_OBJECT__OBJECT (GClosure     *closure,
   g_value_take_object (return_value, v_return);
 }
 
-/* STRING:STRING (./rb-marshal.list:5) */
+/* STRING:STRING (./rb-marshal.list:6) */
 extern void rb_marshal_STRING__STRING (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
@@ -278,7 +327,7 @@ rb_marshal_STRING__STRING (GClosure     *closure,
   g_value_take_string (return_value, v_return);
 }
 
-/* VOID:BOOLEAN,BOOLEAN (./rb-marshal.list:6) */
+/* VOID:BOOLEAN,BOOLEAN (./rb-marshal.list:7) */
 extern void rb_marshal_VOID__BOOLEAN_BOOLEAN (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -321,7 +370,7 @@ rb_marshal_VOID__BOOLEAN_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* BOXED:BOXED (./rb-marshal.list:7) */
+/* BOXED:BOXED (./rb-marshal.list:8) */
 extern void rb_marshal_BOXED__BOXED (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
@@ -366,7 +415,7 @@ rb_marshal_BOXED__BOXED (GClosure     *closure,
   g_value_take_boxed (return_value, v_return);
 }
 
-/* VOID:BOXED,BOXED (./rb-marshal.list:8) */
+/* VOID:BOXED,BOXED (./rb-marshal.list:9) */
 extern void rb_marshal_VOID__BOXED_BOXED (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -409,7 +458,7 @@ rb_marshal_VOID__BOXED_BOXED (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOXED,INT,POINTER,POINTER (./rb-marshal.list:9) */
+/* VOID:BOXED,INT,POINTER,POINTER (./rb-marshal.list:10) */
 extern void rb_marshal_VOID__BOXED_INT_POINTER_POINTER (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
@@ -456,7 +505,50 @@ rb_marshal_VOID__BOXED_INT_POINTER_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOXED,POINTER (./rb-marshal.list:10) */
+/* VOID:BOXED,OBJECT (./rb-marshal.list:11) */
+extern void rb_marshal_VOID__BOXED_OBJECT (GClosure     *closure,
+                                           GValue       *return_value,
+                                           guint         n_param_values,
+                                           const GValue *param_values,
+                                           gpointer      invocation_hint,
+                                           gpointer      marshal_data);
+void
+rb_marshal_VOID__BOXED_OBJECT (GClosure     *closure,
+                               GValue       *return_value,
+                               guint         n_param_values,
+                               const GValue *param_values,
+                               gpointer      invocation_hint,
+                               gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__BOXED_OBJECT) (gpointer     data1,
+                                                   gpointer     arg_1,
+                                                   gpointer     arg_2,
+                                                   gpointer     data2);
+  register GMarshalFunc_VOID__BOXED_OBJECT callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__BOXED_OBJECT) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_boxed (param_values + 1),
+            g_marshal_value_peek_object (param_values + 2),
+            data2);
+}
+
+/* VOID:BOXED,POINTER (./rb-marshal.list:12) */
 extern void rb_marshal_VOID__BOXED_POINTER (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -499,7 +591,7 @@ rb_marshal_VOID__BOXED_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOXED,STRING,BOXED (./rb-marshal.list:11) */
+/* VOID:BOXED,STRING,BOXED (./rb-marshal.list:13) */
 extern void rb_marshal_VOID__BOXED_STRING_BOXED (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -544,7 +636,7 @@ rb_marshal_VOID__BOXED_STRING_BOXED (GClosure     *closure,
             data2);
 }
 
-/* VOID:BOXED,ULONG (./rb-marshal.list:12) */
+/* VOID:BOXED,ULONG (./rb-marshal.list:14) */
 extern void rb_marshal_VOID__BOXED_ULONG (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -587,7 +679,7 @@ rb_marshal_VOID__BOXED_ULONG (GClosure     *closure,
             data2);
 }
 
-/* VOID:DOUBLE,LONG (./rb-marshal.list:13) */
+/* VOID:DOUBLE,LONG (./rb-marshal.list:15) */
 extern void rb_marshal_VOID__DOUBLE_LONG (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -630,7 +722,7 @@ rb_marshal_VOID__DOUBLE_LONG (GClosure     *closure,
             data2);
 }
 
-/* VOID:INT,INT,DOUBLE (./rb-marshal.list:14) */
+/* VOID:INT,INT,DOUBLE (./rb-marshal.list:16) */
 extern void rb_marshal_VOID__INT_INT_DOUBLE (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -675,50 +767,7 @@ rb_marshal_VOID__INT_INT_DOUBLE (GClosure     *closure,
             data2);
 }
 
-/* VOID:INT,POINTER (./rb-marshal.list:15) */
-extern void rb_marshal_VOID__INT_POINTER (GClosure     *closure,
-                                          GValue       *return_value,
-                                          guint         n_param_values,
-                                          const GValue *param_values,
-                                          gpointer      invocation_hint,
-                                          gpointer      marshal_data);
-void
-rb_marshal_VOID__INT_POINTER (GClosure     *closure,
-                              GValue       *return_value,
-                              guint         n_param_values,
-                              const GValue *param_values,
-                              gpointer      invocation_hint,
-                              gpointer      marshal_data)
-{
-  typedef void (*GMarshalFunc_VOID__INT_POINTER) (gpointer     data1,
-                                                  gint         arg_1,
-                                                  gpointer     arg_2,
-                                                  gpointer     data2);
-  register GMarshalFunc_VOID__INT_POINTER callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
-
-  g_return_if_fail (n_param_values == 3);
-
-  if (G_CCLOSURE_SWAP_DATA (closure))
-    {
-      data1 = closure->data;
-      data2 = g_value_peek_pointer (param_values + 0);
-    }
-  else
-    {
-      data1 = g_value_peek_pointer (param_values + 0);
-      data2 = closure->data;
-    }
-  callback = (GMarshalFunc_VOID__INT_POINTER) (marshal_data ? marshal_data : cc->callback);
-
-  callback (data1,
-            g_marshal_value_peek_int (param_values + 1),
-            g_marshal_value_peek_pointer (param_values + 2),
-            data2);
-}
-
-/* VOID:OBJECT,INT,INT (./rb-marshal.list:16) */
+/* VOID:OBJECT,INT,INT (./rb-marshal.list:17) */
 extern void rb_marshal_VOID__OBJECT_INT_INT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -763,7 +812,7 @@ rb_marshal_VOID__OBJECT_INT_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,INT,INT,BOXED,UINT,UINT (./rb-marshal.list:17) */
+/* VOID:OBJECT,INT,INT,BOXED,UINT,UINT (./rb-marshal.list:18) */
 extern void rb_marshal_VOID__OBJECT_INT_INT_BOXED_UINT_UINT (GClosure     *closure,
                                                              GValue       *return_value,
                                                              guint         n_param_values,
@@ -814,7 +863,7 @@ rb_marshal_VOID__OBJECT_INT_INT_BOXED_UINT_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,INT,POINTER (./rb-marshal.list:18) */
+/* VOID:OBJECT,INT,POINTER (./rb-marshal.list:19) */
 extern void rb_marshal_VOID__OBJECT_INT_POINTER (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -859,7 +908,7 @@ rb_marshal_VOID__OBJECT_INT_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,INT (./rb-marshal.list:19) */
+/* VOID:POINTER,INT (./rb-marshal.list:20) */
 extern void rb_marshal_VOID__POINTER_INT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -902,7 +951,7 @@ rb_marshal_VOID__POINTER_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,INT,POINTER (./rb-marshal.list:20) */
+/* VOID:POINTER,INT,POINTER (./rb-marshal.list:21) */
 extern void rb_marshal_VOID__POINTER_INT_POINTER (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
@@ -947,7 +996,52 @@ rb_marshal_VOID__POINTER_INT_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,POINTER (./rb-marshal.list:21) */
+/* VOID:POINTER,LONG,LONG (./rb-marshal.list:22) */
+extern void rb_marshal_VOID__POINTER_LONG_LONG (GClosure     *closure,
+                                                GValue       *return_value,
+                                                guint         n_param_values,
+                                                const GValue *param_values,
+                                                gpointer      invocation_hint,
+                                                gpointer      marshal_data);
+void
+rb_marshal_VOID__POINTER_LONG_LONG (GClosure     *closure,
+                                    GValue       *return_value,
+                                    guint         n_param_values,
+                                    const GValue *param_values,
+                                    gpointer      invocation_hint,
+                                    gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__POINTER_LONG_LONG) (gpointer     data1,
+                                                        gpointer     arg_1,
+                                                        glong        arg_2,
+                                                        glong        arg_3,
+                                                        gpointer     data2);
+  register GMarshalFunc_VOID__POINTER_LONG_LONG callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 4);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__POINTER_LONG_LONG) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_pointer (param_values + 1),
+            g_marshal_value_peek_long (param_values + 2),
+            g_marshal_value_peek_long (param_values + 3),
+            data2);
+}
+
+/* VOID:POINTER,POINTER (./rb-marshal.list:23) */
 extern void rb_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -990,7 +1084,50 @@ rb_marshal_VOID__POINTER_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,ULONG (./rb-marshal.list:22) */
+/* VOID:POINTER,UINT (./rb-marshal.list:24) */
+extern void rb_marshal_VOID__POINTER_UINT (GClosure     *closure,
+                                           GValue       *return_value,
+                                           guint         n_param_values,
+                                           const GValue *param_values,
+                                           gpointer      invocation_hint,
+                                           gpointer      marshal_data);
+void
+rb_marshal_VOID__POINTER_UINT (GClosure     *closure,
+                               GValue       *return_value,
+                               guint         n_param_values,
+                               const GValue *param_values,
+                               gpointer      invocation_hint,
+                               gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__POINTER_UINT) (gpointer     data1,
+                                                   gpointer     arg_1,
+                                                   guint        arg_2,
+                                                   gpointer     data2);
+  register GMarshalFunc_VOID__POINTER_UINT callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__POINTER_UINT) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_pointer (param_values + 1),
+            g_marshal_value_peek_uint (param_values + 2),
+            data2);
+}
+
+/* VOID:POINTER,ULONG (./rb-marshal.list:25) */
 extern void rb_marshal_VOID__POINTER_ULONG (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -1033,7 +1170,7 @@ rb_marshal_VOID__POINTER_ULONG (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,DOUBLE (./rb-marshal.list:23) */
+/* VOID:STRING,DOUBLE (./rb-marshal.list:26) */
 extern void rb_marshal_VOID__STRING_DOUBLE (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -1076,7 +1213,7 @@ rb_marshal_VOID__STRING_DOUBLE (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,INT (./rb-marshal.list:24) */
+/* VOID:STRING,INT (./rb-marshal.list:27) */
 extern void rb_marshal_VOID__STRING_INT (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
@@ -1119,7 +1256,7 @@ rb_marshal_VOID__STRING_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,POINTER (./rb-marshal.list:25) */
+/* VOID:STRING,POINTER (./rb-marshal.list:28) */
 extern void rb_marshal_VOID__STRING_POINTER (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -1162,7 +1299,7 @@ rb_marshal_VOID__STRING_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,STRING (./rb-marshal.list:26) */
+/* VOID:STRING,STRING (./rb-marshal.list:29) */
 extern void rb_marshal_VOID__STRING_STRING (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -1205,7 +1342,52 @@ rb_marshal_VOID__STRING_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,STRING,STRING (./rb-marshal.list:27) */
+/* VOID:STRING,STRING,OBJECT (./rb-marshal.list:30) */
+extern void rb_marshal_VOID__STRING_STRING_OBJECT (GClosure     *closure,
+                                                   GValue       *return_value,
+                                                   guint         n_param_values,
+                                                   const GValue *param_values,
+                                                   gpointer      invocation_hint,
+                                                   gpointer      marshal_data);
+void
+rb_marshal_VOID__STRING_STRING_OBJECT (GClosure     *closure,
+                                       GValue       *return_value,
+                                       guint         n_param_values,
+                                       const GValue *param_values,
+                                       gpointer      invocation_hint,
+                                       gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__STRING_STRING_OBJECT) (gpointer     data1,
+                                                           gpointer     arg_1,
+                                                           gpointer     arg_2,
+                                                           gpointer     arg_3,
+                                                           gpointer     data2);
+  register GMarshalFunc_VOID__STRING_STRING_OBJECT callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 4);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__STRING_STRING_OBJECT) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_string (param_values + 1),
+            g_marshal_value_peek_string (param_values + 2),
+            g_marshal_value_peek_object (param_values + 3),
+            data2);
+}
+
+/* VOID:STRING,STRING,STRING (./rb-marshal.list:31) */
 extern void rb_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
@@ -1250,7 +1432,7 @@ rb_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,STRING,STRING,UINT,BOOLEAN (./rb-marshal.list:28) */
+/* VOID:STRING,STRING,STRING,UINT,BOOLEAN (./rb-marshal.list:32) */
 extern void rb_marshal_VOID__STRING_STRING_STRING_UINT_BOOLEAN (GClosure     *closure,
                                                                 GValue       *return_value,
                                                                 guint         n_param_values,
@@ -1299,7 +1481,7 @@ rb_marshal_VOID__STRING_STRING_STRING_UINT_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:ULONG,FLOAT (./rb-marshal.list:29) */
+/* VOID:ULONG,FLOAT (./rb-marshal.list:33) */
 extern void rb_marshal_VOID__ULONG_FLOAT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -1342,7 +1524,7 @@ rb_marshal_VOID__ULONG_FLOAT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,BOOLEAN (./rb-marshal.list:30) */
+/* VOID:OBJECT,BOOLEAN (./rb-marshal.list:34) */
 extern void rb_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -1385,7 +1567,7 @@ rb_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,STRING,POINTER,POINTER (./rb-marshal.list:31) */
+/* VOID:STRING,STRING,POINTER,POINTER (./rb-marshal.list:35) */
 extern void rb_marshal_VOID__STRING_STRING_POINTER_POINTER (GClosure     *closure,
                                                             GValue       *return_value,
                                                             guint         n_param_values,
