@@ -13,10 +13,12 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301  USA.
  */
 
+#include "config.h"
+
 #include <string.h>
 #include <gtk/gtktreeselection.h>
 #include <gtk/gtksignal.h>
@@ -117,11 +119,11 @@ rb_tree_drag_source_row_draggable (RbTreeDragSource *drag_source,
   RbTreeDragSourceIface *iface = RB_TREE_DRAG_SOURCE_GET_IFACE (drag_source);
 
   g_return_val_if_fail (RB_IS_TREE_DRAG_SOURCE (drag_source), FALSE);
-  g_return_val_if_fail (iface->row_draggable != NULL, FALSE);
+  g_return_val_if_fail (iface->rb_row_draggable != NULL, FALSE);
   g_return_val_if_fail (path_list != NULL, FALSE);
 
-  if (iface->row_draggable)
-    return (* iface->row_draggable) (drag_source, path_list);
+  if (iface->rb_row_draggable)
+    return (* iface->rb_row_draggable) (drag_source, path_list);
   else
     return TRUE;
 }
@@ -147,10 +149,10 @@ rb_tree_drag_source_drag_data_delete (RbTreeDragSource *drag_source,
   RbTreeDragSourceIface *iface = RB_TREE_DRAG_SOURCE_GET_IFACE (drag_source);
 
   g_return_val_if_fail (RB_IS_TREE_DRAG_SOURCE (drag_source), FALSE);
-  g_return_val_if_fail (iface->drag_data_delete != NULL, FALSE);
+  g_return_val_if_fail (iface->rb_drag_data_delete != NULL, FALSE);
   g_return_val_if_fail (path_list != NULL, FALSE);
 
-  return (* iface->drag_data_delete) (drag_source, path_list);
+  return (* iface->rb_drag_data_delete) (drag_source, path_list);
 }
 
 /**
@@ -174,11 +176,11 @@ rb_tree_drag_source_drag_data_get    (RbTreeDragSource *drag_source,
   RbTreeDragSourceIface *iface = RB_TREE_DRAG_SOURCE_GET_IFACE (drag_source);
 
   g_return_val_if_fail (RB_IS_TREE_DRAG_SOURCE (drag_source), FALSE);
-  g_return_val_if_fail (iface->drag_data_get != NULL, FALSE);
+  g_return_val_if_fail (iface->rb_drag_data_get != NULL, FALSE);
   g_return_val_if_fail (path_list != NULL, FALSE);
   g_return_val_if_fail (selection_data != NULL, FALSE);
 
-  return (* iface->drag_data_get) (drag_source, path_list, selection_data);
+  return (* iface->rb_drag_data_get) (drag_source, path_list, selection_data);
 }
 
 
@@ -220,10 +222,10 @@ rb_tree_drag_dest_drag_data_received (RbTreeDragDest   *drag_dest,
   RbTreeDragDestIface *iface = RB_TREE_DRAG_DEST_GET_IFACE (drag_dest);
 
   g_return_val_if_fail (RB_IS_TREE_DRAG_DEST (drag_dest), FALSE);
-  g_return_val_if_fail (iface->drag_data_received != NULL, FALSE);
+  g_return_val_if_fail (iface->rb_drag_data_received != NULL, FALSE);
   g_return_val_if_fail (selection_data != NULL, FALSE);
 
-  return (* iface->drag_data_received) (drag_dest, dest, pos, selection_data);
+  return (* iface->rb_drag_data_received) (drag_dest, dest, pos, selection_data);
 }
 
 
@@ -237,10 +239,10 @@ rb_tree_drag_dest_row_drop_possible (RbTreeDragDest   *drag_dest,
   RbTreeDragDestIface *iface = RB_TREE_DRAG_DEST_GET_IFACE (drag_dest);
 
   g_return_val_if_fail (RB_IS_TREE_DRAG_DEST (drag_dest), FALSE);
-  g_return_val_if_fail (iface->drag_data_received != NULL, FALSE);
+  g_return_val_if_fail (iface->rb_row_drop_possible != NULL, FALSE);
   g_return_val_if_fail (selection_data != NULL, FALSE);
 
-  return (* iface->row_drop_possible) (drag_dest, dest_path, pos, selection_data);
+  return (* iface->rb_row_drop_possible) (drag_dest, dest_path, pos, selection_data);
 }
 
 
@@ -253,11 +255,21 @@ rb_tree_drag_dest_row_drop_position (RbTreeDragDest   *drag_dest,
   RbTreeDragDestIface *iface = RB_TREE_DRAG_DEST_GET_IFACE (drag_dest);
 
   g_return_val_if_fail (RB_IS_TREE_DRAG_DEST (drag_dest), FALSE);
-  g_return_val_if_fail (iface->row_drop_position != NULL, FALSE);
+  g_return_val_if_fail (iface->rb_row_drop_position != NULL, FALSE);
   g_return_val_if_fail (targets != NULL, FALSE);
   g_return_val_if_fail (pos != NULL, FALSE);
 
-  return (* iface->row_drop_position) (drag_dest, dest_path, targets, pos);
+  return (* iface->rb_row_drop_position) (drag_dest, dest_path, targets, pos);
+}
+
+static void
+rb_tree_dnd_data_free (gpointer data)
+{
+  RbTreeDndData *priv_data = data;
+
+  gtk_target_list_unref (priv_data->source_target_list);
+
+  g_free (priv_data);
 }
 
 RbTreeDndData *
@@ -270,7 +282,7 @@ init_rb_tree_dnd_data (GtkWidget *widget)
 	{
 		priv_data = g_new0 (RbTreeDndData, 1);
 		priv_data->pending_event = FALSE;
-		g_object_set_data (G_OBJECT (widget), RB_TREE_DND_STRING, priv_data);
+		g_object_set_data_full (G_OBJECT (widget), RB_TREE_DND_STRING, priv_data, rb_tree_dnd_data_free);
 		priv_data->drag_motion_handler = 0;
 		priv_data->drag_leave_handler = 0;
 		priv_data->button_press_event_handler = 0;
@@ -433,7 +445,9 @@ scroll_row_timeout (gpointer data)
 	value = CLAMP (vadj->value + offset, vadj->lower, vadj->upper - vadj->page_size);
 	gtk_adjustment_set_value (vadj, value);
 
-	remove_select_on_drag_timeout(tree_view);
+	/* don't remove it if we're on the edge and not scrolling */
+	if (ABS (vadj->value - value) > 0.0001)
+		remove_select_on_drag_timeout(tree_view);
 
 	GDK_THREADS_LEAVE ();
 
@@ -728,11 +742,11 @@ rb_tree_dnd_drag_drop_cb (GtkWidget        *widget,
 
 		GdkAtom target;
 		RbTreeDragDestIface *iface = RB_TREE_DRAG_DEST_GET_IFACE (model);
-		if (iface->get_drag_target) {
+		if (iface->rb_get_drag_target) {
 			RbTreeDragDest *dest = RB_TREE_DRAG_DEST (model);
-			target = (* iface->get_drag_target) (dest, widget, 
-							     context, path, 
-							     priv_data->dest_target_list);
+			target = (* iface->rb_get_drag_target) (dest, widget, 
+								context, path, 
+								priv_data->dest_target_list);
 		} else {
 			target = gtk_drag_dest_find_target (widget, context, 
 							    priv_data->dest_target_list);
