@@ -623,7 +623,6 @@ rb_metadata_gst_load_tag (const GstTagList *list, const gchar *tag, RBMetaData *
 		 * and then remove leading and trailing whitespace.
 		 */
 		char *str;
-		const char *old_str;
 
 		str = g_value_dup_string (newval);
 
@@ -638,15 +637,20 @@ rb_metadata_gst_load_tag (const GstTagList *list, const gchar *tag, RBMetaData *
 
 		/* Check whether we have a shorter duplicate tag,
 		 * Doesn't work with non-normalised UTF-8 strings */
-		old_str = g_value_get_string (val);
-		if (old_str != NULL
-		    && g_utf8_strlen (old_str, -1) > g_utf8_strlen (str, -1)) {
-			if (g_str_has_prefix (old_str, str) != FALSE) {
-				rb_debug ("Got shorter duplicate tag");
-				g_free (str);
-				g_value_unset (newval);
-				g_free (newval);
-				return;
+		val = g_hash_table_lookup (md->priv->metadata,
+					   GINT_TO_POINTER (field));
+		if (val != NULL) {
+			const char *old_str;
+			old_str = g_value_get_string (val);
+			if (old_str != NULL
+			    && g_utf8_strlen (old_str, -1) > g_utf8_strlen (str, -1)) {
+				if (g_str_has_prefix (old_str, str) != FALSE) {
+					rb_debug ("Got shorter duplicate tag");
+					g_free (str);
+					g_value_unset (newval);
+					g_free (newval);
+					return;
+				}
 			}
 		}
 		g_value_take_string (newval, str);
@@ -738,10 +742,7 @@ rb_metadata_gst_new_decoded_pad_cb (GstElement *decodebin, GstPad *pad, gboolean
 
 	gst_caps_unref (caps);
 
-	/* if this is non-audio, cancel the operation
-	 * under 0.8 this causes assertion faliures when a pad with no caps in found
-	 * it isn't /needed/ under 0.8, so we don't do it.
-	 *
+	/* If this is non-audio, cancel the operation.
 	 * This seems to cause some deadlocks with video files, so only do it
 	 * when we get no/any caps.
 	 */
@@ -813,6 +814,12 @@ rb_metadata_bus_handler (GstBus *bus, GstMessage *message, RBMetaData *md)
 		if (gerror->domain == GST_STREAM_ERROR &&
 		    gerror->code == GST_STREAM_ERROR_TYPE_NOT_FOUND) {
 			rb_debug ("caught type not found error");
+		} else if (gerror->domain == GST_STREAM_ERROR &&
+			   gerror->code == GST_STREAM_ERROR_WRONG_TYPE &&
+			   md->priv->type != NULL &&
+			   strcmp (md->priv->type, "text/plain") == 0) {
+			rb_debug ("got WRONG_TYPE error for text/plain: setting non-audio flag");
+			md->priv->non_audio = TRUE;
 		} else if (md->priv->error) {
 			rb_debug ("caught error: %s, but we've already got one", gerror->message);
 		} else {
@@ -985,7 +992,7 @@ rb_metadata_load (RBMetaData *md,
 	       change_timeout < 5) {
 		GstMessage *msg;
 
-		msg = gst_bus_timed_pop (bus, 1 * GST_SECOND);
+		msg = gst_bus_poll (bus, GST_MESSAGE_ANY, 1 * GST_SECOND);
 		if (msg) {
 			rb_metadata_bus_handler (bus, msg, md);
 			gst_message_unref (msg);
@@ -998,10 +1005,10 @@ rb_metadata_load (RBMetaData *md,
 	}
 	gst_object_unref (GST_OBJECT (bus));
 
+	rb_metadata_event_loop (md, GST_ELEMENT (pipeline), FALSE);
 
 	if (state_ret != GST_STATE_CHANGE_SUCCESS) {
 		rb_debug ("failed to go to PAUSED for %s", uri);
-		rb_metadata_event_loop (md, GST_ELEMENT (pipeline), FALSE);
 		if (!md->priv->non_audio && md->priv->error == NULL)
 			g_set_error (error,
 				     RB_METADATA_ERROR,
@@ -1012,7 +1019,7 @@ rb_metadata_load (RBMetaData *md,
 
 	if (state_ret == GST_STATE_CHANGE_SUCCESS) {
 
-		/* We caught the went to PAUSED,
+		/* The pipeline went to PAUSED,
 		 * which means the decoder should have read all
 		 * of the metadata, and should know the length now.
 		 */
@@ -1195,8 +1202,9 @@ rb_metadata_save (RBMetaData *md, GError **error)
 {
 	GstElement *pipeline = NULL;
 	GstElement *gnomevfssrc = NULL;
-        GstElement *retag_end = NULL; /* the last elemet after retagging subpipeline */
+        GstElement *retag_end = NULL; /* the last element after retagging subpipeline */
 	const char *plugin_name = NULL;
+	char *tmpname_prefix = NULL;
 	char *tmpname = NULL;
 	GnomeVFSHandle *handle = NULL;
 	GnomeVFSResult result;
@@ -1207,7 +1215,12 @@ rb_metadata_save (RBMetaData *md, GError **error)
 
 	rb_debug ("saving metadata for uri: %s", md->priv->uri);
 
-	if ((result = rb_uri_mkstemp (md->priv->uri, &tmpname, &handle)) != GNOME_VFS_OK)
+	tmpname_prefix = rb_uri_make_hidden (md->priv->uri);
+	rb_debug ("temporary file name prefix: %s", tmpname_prefix);
+
+	result = rb_uri_mkstemp (tmpname_prefix, &tmpname, &handle);
+	g_free (tmpname_prefix);
+	if (result != GNOME_VFS_OK)
 		goto vfs_error;
 
 	pipeline = gst_pipeline_new ("pipeline");
