@@ -33,20 +33,11 @@
 #include "rb-preferences.h"
 #include "rb-marshal.h"
 
-/* Play Orders */
-#include "rb-play-order-linear.h"
-#include "rb-play-order-linear-loop.h"
-#include "rb-play-order-shuffle.h"
-#include "rb-play-order-random-equal-weights.h"
-#include "rb-play-order-random-by-age.h"
-#include "rb-play-order-random-by-rating.h"
-#include "rb-play-order-random-by-age-and-rating.h"
-#include "rb-play-order-queue.h"
-
 static void rb_play_order_class_init (RBPlayOrderClass *klass);
 static void rb_play_order_init (RBPlayOrder *porder);
 static GObject *rb_play_order_constructor (GType type, guint n_construct_properties,
 					   GObjectConstructParam *construct_properties);
+static void rb_play_order_dispose (GObject *object);
 static void rb_play_order_finalize (GObject *object);
 static void rb_play_order_set_property (GObject *object,
 					guint prop_id,
@@ -111,6 +102,7 @@ rb_play_order_class_init (RBPlayOrderClass *klass)
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
 	object_class->constructor = rb_play_order_constructor;
+	object_class->dispose = rb_play_order_dispose;
 	object_class->finalize = rb_play_order_finalize;
 	object_class->set_property = rb_play_order_set_property;
 	object_class->get_property = rb_play_order_get_property;
@@ -168,7 +160,7 @@ rb_play_order_constructor (GType type,
 }
 
 static void
-rb_play_order_finalize (GObject *object)
+rb_play_order_dispose (GObject *object)
 {
 	RBPlayOrder *porder;
 
@@ -177,10 +169,6 @@ rb_play_order_finalize (GObject *object)
 
 	porder = RB_PLAY_ORDER (object);
 
-	if (porder->priv->playing_entry != NULL) {
-		rhythmdb_entry_unref (porder->priv->playing_entry);
-	}
-
 	if (porder->priv->query_model != NULL) {
 		g_signal_handlers_disconnect_by_func (G_OBJECT (porder->priv->query_model),
 						      G_CALLBACK (rb_play_order_entry_added_cb),
@@ -189,12 +177,32 @@ rb_play_order_finalize (GObject *object)
 						      G_CALLBACK (rb_play_order_row_deleted_cb),
 						      porder);
 		g_object_unref (porder->priv->query_model);
+		porder->priv->query_model = NULL;
 	}
 
 	if (porder->priv->db != NULL) {
 		g_object_unref (porder->priv->db);
+		porder->priv->db = NULL;
 	}
 
+	if (porder->priv->playing_entry != NULL) {
+		rhythmdb_entry_unref (porder->priv->playing_entry);
+		porder->priv->playing_entry = NULL;
+	}
+
+	G_OBJECT_CLASS (rb_play_order_parent_class)->dispose (object);
+}
+
+static void
+rb_play_order_finalize (GObject *object)
+{
+	RBPlayOrder *porder;
+
+	g_return_if_fail (object != NULL);
+	g_return_if_fail (RB_IS_PLAY_ORDER (object));
+
+	porder = RB_PLAY_ORDER (object);
+
 	G_OBJECT_CLASS (rb_play_order_parent_class)->finalize (object);
 }
 
@@ -271,72 +279,6 @@ rb_play_order_get_property (GObject *object,
 	}
 }
 
-/**
- * rb_play_order_get_orders:
- *
- * Defines the set of available play orders, their translatable descriptions, their
- * constructor functions, whether they should appear in a drop-down list of
- * play orders, and which one is the default.
- *
- * This should be the only function with full knowledge of what play orders are
- * available.
- */
-const RBPlayOrderDescription *
-rb_play_order_get_orders (void)
-{
-	/* Exactly one entry must have is_default==TRUE. Otherwise you will
-	 * cause a g_assert(). */
-	static const RBPlayOrderDescription orders[] = {
-		{ "linear", N_("Linear"), rb_linear_play_order_new, TRUE, TRUE },
-		{ "linear-loop", N_("Linear looping"), rb_linear_play_order_loop_new, TRUE, FALSE },
-		{ "shuffle", N_("Shuffle"), rb_shuffle_play_order_new, TRUE, FALSE },
-		{ "random-equal-weights", N_("Random with equal weights"), rb_random_play_order_equal_weights_new, TRUE, FALSE },
-		{ "random-by-age", N_("Random by time since last play"), rb_random_play_order_by_age_new, TRUE, FALSE },
-		{ "random-by-rating", N_("Random by rating"), rb_random_play_order_by_rating_new, TRUE, FALSE },
-		{ "random-by-age-and-rating", N_("Random by time since last play and rating"), rb_random_play_order_by_age_and_rating_new, TRUE, FALSE },
-		{ "queue", N_("Linear, removing entries once played"), rb_queue_play_order_new, FALSE, FALSE },
-		{ NULL, NULL, NULL },
-	};
-	return orders;
-}
-
-/**
- * rb_play_order_new:
- * @porder_name: Play order type name
- * @player: #RBShellPlayer instance to attach to
- *
- * Creates a new #RBPlayOrder of the specified type.
- *
- * Returns: #RBPlayOrder instance
- **/
-RBPlayOrder *
-rb_play_order_new (const char* porder_name,
-		   RBShellPlayer *player)
-{
-	int default_index = -1;
-	const RBPlayOrderDescription *orders = rb_play_order_get_orders ();
-	int i;
-
-	g_return_val_if_fail (porder_name != NULL, NULL);
-	g_return_val_if_fail (player != NULL, NULL);
-
-	for (i=0; orders[i].name != NULL; ++i) {
-		if (strcmp (orders[i].name, porder_name) == 0)
-			return orders[i].constructor (player);
-		if (orders[i].is_default) {
-			/* There must not be two default play orders */
-			g_assert (default_index == -1);
-			default_index = i;
-		}
-	}
-	/* There must be a default play order */
-	g_assert (default_index != -1);
-
-	g_warning ("Unknown value \"%s\" in GConf key \"" CONF_STATE_PLAY_ORDER
-			"\". Using %s play order.", porder_name, orders[default_index].name);
-	return orders[default_index].constructor (player);
-}
-
 /**
  * rb_play_order_get_player:
  * @porder: #RBPlayOrder instance
