@@ -54,6 +54,7 @@ typedef enum
 	RB_SHELL_UI_LOCATION_SIDEBAR,
 	RB_SHELL_UI_LOCATION_MAIN_TOP,
 	RB_SHELL_UI_LOCATION_MAIN_BOTTOM,
+	RB_SHELL_UI_LOCATION_MAIN_NOTEBOOK
 } RBShellUILocation;
 
 GType rb_shell_ui_location_get_type (void);
@@ -79,8 +80,7 @@ typedef struct
 
 GType		rb_shell_get_type	(void);
 
-RBShell *	rb_shell_new		(int argc, char **argv,
-					 gboolean no_registration,
+RBShell *	rb_shell_new		(gboolean no_registration,
 					 gboolean no_update,
 					 gboolean dry_run,
 					 char *rhythmdb,
@@ -137,6 +137,12 @@ void            rb_shell_hidden_notify  (RBShell *shell,
 					 GtkWidget *icon,
 					 const char *secondary,
 					 gboolean requested);
+void            rb_shell_hidden_notify_markup  (RBShell *shell,
+						guint timeout,
+						const char *primary_markup,
+						GtkWidget *icon,
+						const char *secondary_markup,
+						gboolean requested);
 void		rb_shell_notify_playing_entry (RBShell *shell,
 					       RhythmDBEntry *entry,
 					       gboolean requested);
@@ -154,8 +160,9 @@ gboolean        rb_shell_get_party_mode (RBShell *shell);
 
 void rb_shell_append_source (RBShell *shell, RBSource *source, RBSource *parent);
 
-void rb_shell_add_widget (RBShell *shell, GtkWidget *widget, RBShellUILocation location);
-void rb_shell_remove_widget (RBShell *shell, GtkWidget *widget, RBShellUILocation location);
+void 		rb_shell_add_widget (RBShell *shell, GtkWidget *widget, RBShellUILocation location);
+void 		rb_shell_remove_widget (RBShell *shell, GtkWidget *widget, RBShellUILocation location);
+void		rb_shell_notebook_set_page (RBShell *shell, GtkWidget *widget);
 
 G_END_DECLS
 
