@@ -36,6 +36,22 @@ G_BEGIN_DECLS
 #define RB_IS_SOURCELIST_MODEL_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((obj), RB_TYPE_SOURCELIST_MODEL))
 #define RB_SOURCELIST_MODEL_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj), RB_TYPE_SOURCELIST_MODEL, RBSourceListModelClass))
 
+typedef enum {
+	RB_SOURCELIST_MODEL_COLUMN_PLAYING = 0,
+	RB_SOURCELIST_MODEL_COLUMN_PIXBUF,
+	RB_SOURCELIST_MODEL_COLUMN_NAME,
+	RB_SOURCELIST_MODEL_COLUMN_SOURCE,
+	RB_SOURCELIST_MODEL_COLUMN_ATTRIBUTES,
+	RB_SOURCELIST_MODEL_COLUMN_VISIBILITY,
+	RB_SOURCELIST_MODEL_COLUMN_IS_GROUP,
+	RB_SOURCELIST_MODEL_COLUMN_GROUP_CATEGORY,
+	RB_SOURCELIST_MODEL_N_COLUMNS
+} RBSourceListModelColumn;
+
+GType rb_sourcelist_model_column_get_type (void);
+#define RB_TYPE_SOURCELIST_MODEL_COLUMN (rb_sourcelist_model_column_get_type ())
+
+
 typedef struct RBSourceListModelPrivate RBSourceListModelPrivate;
 
 typedef struct RBSourceListModel
@@ -53,28 +69,12 @@ typedef struct RBSourceListModelClass
 
 } RBSourceListModelClass;
 
-enum
-{
-	RB_SOURCELIST_MODEL_COLUMN_PLAYING = 0,
-	RB_SOURCELIST_MODEL_COLUMN_PIXBUF,
-	RB_SOURCELIST_MODEL_COLUMN_NAME,
-	RB_SOURCELIST_MODEL_COLUMN_SOURCE,
-	RB_SOURCELIST_MODEL_COLUMN_ATTRIBUTES,
-	RB_SOURCELIST_MODEL_COLUMN_VISIBILITY,
-	RB_SOURCELIST_MODEL_N_COLUMNS
-};
-
 GType		rb_sourcelist_model_get_type	(void);
 
 GtkTreeModel *	rb_sourcelist_model_new		(void);
 
 void		rb_sourcelist_model_set_dnd_targets (RBSourceListModel *sourcelist,
 						     GtkTreeView *treeview);
-GtkTreePath *	rb_sourcelist_model_get_group_path (RBSourceListModel *sourcelist,
-						    RBSourceListGroup group);
-gboolean	rb_sourcelist_model_row_is_separator (GtkTreeModel *model,
-						      GtkTreeIter *iter,
-						      RBSourceListModel *sourcelist);
 
 G_END_DECLS
 
