@@ -79,6 +79,9 @@ enum
 
 static void rb_sourcelist_class_init (RBSourceListClass *klass);
 static void rb_sourcelist_init (RBSourceList *sourcelist);
+static GObject * rb_sourcelist_constructor (GType type,
+					    guint n_construct_properties,
+					    GObjectConstructParam *construct_properties);
 static void rb_sourcelist_finalize (GObject *object);
 static void rb_sourcelist_set_property (GObject *object,
 					guint prop_id,
@@ -112,6 +115,7 @@ rb_sourcelist_class_init (RBSourceListClass *class)
 	o_class = (GObjectClass *) class;
 	object_class = (GtkObjectClass *) class;
 
+	o_class->constructor = rb_sourcelist_constructor;
 	o_class->finalize = rb_sourcelist_finalize;
 	o_class->set_property = rb_sourcelist_set_property;
 	o_class->get_property = rb_sourcelist_get_property;
@@ -178,6 +182,22 @@ rb_sourcelist_class_init (RBSourceListClass *class)
 	g_type_class_add_private (class, sizeof (RBSourceListPrivate));
 }
 
+static GObject *
+rb_sourcelist_constructor (GType type,
+			   guint n_construct_properties,
+			   GObjectConstructParam *construct_properties)
+{
+	RBSourceList *sourcelist;
+
+	sourcelist = RB_SOURCELIST (G_OBJECT_CLASS (rb_sourcelist_parent_class)
+			->constructor (type, n_construct_properties, construct_properties));
+
+	gtk_container_add (GTK_CONTAINER (sourcelist),
+			   sourcelist->priv->treeview);
+
+	return G_OBJECT (sourcelist);
+}
+
 static void
 rb_sourcelist_cell_set_background (RBSourceList       *list,
 				   GtkCellRenderer    *cell,
@@ -794,9 +814,6 @@ rb_sourcelist_new (RBShell *shell)
 						  "shell", shell,
 					          NULL));
 
-	gtk_container_add (GTK_CONTAINER (sourcelist),
-			   sourcelist->priv->treeview);
-
 	return GTK_WIDGET (sourcelist);
 }
 
